@@ -3,9 +3,7 @@ from typing import List
 import pytest
 from haystack.dataclasses.document import Document
 from haystack.testing.document_store import FilterDocumentsTest
-from pandas import DataFrame
 from psycopg.sql import SQL
-from psycopg.types.json import Jsonb
 
 from haystack_integrations.document_stores.pgvector.filters import (
     FilterError,
@@ -40,6 +38,62 @@ class TestFilters(FilterDocumentsTest):
     @pytest.mark.skip(reason="NOT operator is not supported in PgvectorDocumentStore")
     def test_not_operator(self, document_store, filterable_docs): ...
 
+    def test_like_operator(self, document_store, filterable_docs):
+        document_store.write_documents(filterable_docs)
+        filters = {"field": "content", "operator": "like", "value": "%Foo%"}
+        result = document_store.filter_documents(filters=filters)
+
+        self.assert_documents_are_equal(result, [d for d in filterable_docs if "Foo" in d.content])
+
+    def test_like_operator_startswith(self, document_store, filterable_docs):
+        document_store.write_documents(filterable_docs)
+        filters = {"field": "content", "operator": "like", "value": "Foo%"}
+        result = document_store.filter_documents(filters=filters)
+
+        self.assert_documents_are_equal(result, [d for d in filterable_docs if d.content.startswith("Foo")])
+
+    def test_like_operator_nb_chars(self, document_store, filterable_docs):
+        document_store.write_documents(filterable_docs)
+        filters = {"field": "content", "operator": "like", "value": "A Foobar Document__"}
+        result = document_store.filter_documents(filters=filters)
+
+        self.assert_documents_are_equal(
+            result,
+            [
+                d
+                for d in filterable_docs
+                if (d.content.startswith("A Foobar Document") and len(d.content) == (len("A Foobar Document") + 2))
+            ],
+        )
+
+    def test_not_like_operator(self, document_store, filterable_docs):
+        document_store.write_documents(filterable_docs)
+        filters = {"field": "content", "operator": "not like", "value": "%Foo%"}
+        result = document_store.filter_documents(filters=filters)
+
+        self.assert_documents_are_equal(result, [d for d in filterable_docs if "Foo" not in d.content])
+
+    def test_not_like_operator_startswith(self, document_store, filterable_docs):
+        document_store.write_documents(filterable_docs)
+        filters = {"field": "content", "operator": "not like", "value": "Foo%"}
+        result = document_store.filter_documents(filters=filters)
+
+        self.assert_documents_are_equal(result, [d for d in filterable_docs if not d.content.startswith("Foo")])
+
+    def test_not_like_operator_nb_chars(self, document_store, filterable_docs):
+        document_store.write_documents(filterable_docs)
+        filters = {"field": "content", "operator": "not like", "value": "A Foobar Document__"}
+        result = document_store.filter_documents(filters=filters)
+
+        self.assert_documents_are_equal(
+            result,
+            [
+                d
+                for d in filterable_docs
+                if not (d.content.startswith("A Foobar Document") and len(d.content) == (len("A Foobar Document") + 2))
+            ],
+        )
+
     def test_complex_filter(self, document_store, filterable_docs):
         document_store.write_documents(filterable_docs)
         filters = {
@@ -91,17 +145,6 @@ def test_treat_meta_field():
     assert _treat_meta_field(field="meta.name", value=None) == "meta->>'name'"
 
 
-def test_comparison_condition_dataframe_jsonb_conversion():
-    dataframe = DataFrame({"a": [1, 2, 3], "b": ["a", "b", "c"]})
-    condition = {"field": "meta.df", "operator": "==", "value": dataframe}
-    field, values = _parse_comparison_condition(condition)
-    assert field == "(meta.df)::jsonb = %s"
-
-    # we check each slot of the Jsonb object because it does not implement __eq__
-    assert values[0].obj == Jsonb(dataframe.to_json()).obj
-    assert values[0].dumps == Jsonb(dataframe.to_json()).dumps
-
-
 def test_comparison_condition_missing_operator():
     condition = {"field": "meta.type", "value": "article"}
     with pytest.raises(FilterError):
